NAME

Mail::Message::Part - a part of a message, but a message by itself

INHERITANCE

Mail::Message::Part
  is a Mail::Message
  is a Mail::Reporter

SYNOPSIS

my Mail::Message $message = ...;
if($message->isMultipart) {
   my Mail::Message::Part $part;

   foreach $part ($message->body->parts) {
      $part->print(\*OUT);
      my $attached_head = $part->head;
      my $attached_body = $part->body;      # encoded as read
      my $attached_body = $part->decoded;   # transfer-encoding removed
   }
}

DESCRIPTION

A Mail::Message::Part object contains a message which is included in the body of an other message. For instance attachments are parts.

READ Mail::Message FIRST. A part is a special message: it has a reference to its parent message, and will usually not be sub-classed into mail folder specific variants.

METHODS

$obj->printEscapedFrom(FILEHANDLE)

Prints the message part, but all lines which start with 'From ' will get a leading gt. See Mail::Message::Body::printEscapedFrom().

Constructors

$obj->clone

See "Constructors" in Mail::Message

Mail::Message::Part->coerce(BODY|MESSAGE, MULTIPART, HEADERS)

Transforms a BODY or MESSAGE to a real message part. The MULTIPART refers to the parental body.

When ta BODY is specified, extra HEADERS can be supplied as well. Bodies are coerced into message parts by calling buildFromBody(). If you specify a MESSAGE residing in a folder, this message will automatically be cloned.

Mail::Message::Part->new(OPTIONS)

Create a message part.

Option      Defined in       Default                                                       
body        L<Mail::Message>  undef                                                         
body_type   L<Mail::Message>  L<Mail::Message::Body::Lines|Mail::Message::Body::Lines>      
container                    <required>                                                    
field_type  L<Mail::Message>  undef                                                         
head        L<Mail::Message>  <empty header>                                                
head_type   L<Mail::Message>  L<Mail::Message::Head::Complete|Mail::Message::Head::Complete>
labels      L<Mail::Message>  {}                                                            
log         L<Mail::Reporter>  C<'WARNINGS'>                                                 
messageId   L<Mail::Message>  undef                                                         
modified    L<Mail::Message>  <false>                                                       
trace       L<Mail::Reporter>  C<'WARNINGS'>                                                 
trusted     L<Mail::Message>  <false>                                                       

. body OBJECT

. body_type CLASS

. container BODY

Reference to the parental Mail::Message::Body object where this part is a member of. That object may be a Mail::Message::Body::Multipart or a Mail::Message::Body::Nested.

. field_type CLASS

. head OBJECT

. head_type CLASS

. labels ARRAY|HASH

. log LEVEL

. messageId STRING

. modified BOOLEAN

. trace LEVEL

. trusted BOOLEAN

Constructing a message

$obj->bounce([RG-OBJECT|OPTIONS])

See "Constructing a message" in Mail::Message::Construct::Bounce

Mail::Message::Part->build([MESSAGE|BODY], CONTENT)

See "Constructing a message" in Mail::Message::Construct::Build

Mail::Message::Part->buildFromBody(BODY, CONTAINER, HEADERS)

Shape a message part around a BODY. Bodies have information about their content in them, which is used to construct a header for the message. Next to that, more HEADERS can be specified. No headers are obligatory. No extra headers are fabricated automatically.

Example:

my $multi = Mail::Message::Body::Multipart->new;
my $part  = Mail::Message::Part->buildFromBody($body, $multi);

$obj->forward(OPTIONS)

See "Constructing a message" in Mail::Message::Construct::Forward

$obj->forwardPostlude

See "Constructing a message" in Mail::Message::Construct::Forward

$obj->forwardPrelude

See "Constructing a message" in Mail::Message::Construct::Forward

$obj->forwardSubject(STRING)

See "Constructing a message" in Mail::Message::Construct::Forward

Mail::Message::Part->read(FILEHANDLE|SCALAR|REF-SCALAR|ARRAY-OF-LINES, OPTIONS)

See "Constructing a message" in Mail::Message::Construct::Read

$obj->rebuild(OPTIONS)

See "Constructing a message" in Mail::Message::Construct::Rebuild

$obj->reply(OPTIONS)

See "Constructing a message" in Mail::Message::Construct::Reply

$obj->replyPrelude([STRING|FIELD|ADDRESS])

See "Constructing a message" in Mail::Message::Construct::Reply

$obj->replySubject(STRING)

Mail::Message::Part->replySubject(STRING)

See "Constructing a message" in Mail::Message::Construct::Reply

The Message

$obj->container

See "The Message" in Mail::Message

$obj->isDummy

See "The Message" in Mail::Message

$obj->isPart

See "The Message" in Mail::Message

$obj->messageId

See "The Message" in Mail::Message

$obj->print([FILEHANDLE])

See "The Message" in Mail::Message

$obj->send([MAILER], OPTIONS)

See "The Message" in Mail::Message

$obj->size

See "The Message" in Mail::Message

$obj->toplevel

See "The Message" in Mail::Message

$obj->write([FILEHANDLE])

See "The Message" in Mail::Message

The header

$obj->bcc

See "The header" in Mail::Message

$obj->cc

See "The header" in Mail::Message

$obj->date

See "The header" in Mail::Message

$obj->destinations

See "The header" in Mail::Message

$obj->from

See "The header" in Mail::Message

$obj->get(FIELDNAME)

See "The header" in Mail::Message

$obj->guessTimestamp

See "The header" in Mail::Message

$obj->head([HEAD])

See "The header" in Mail::Message

$obj->nrLines

See "The header" in Mail::Message

$obj->sender

See "The header" in Mail::Message

$obj->study(FIELDNAME)

See "The header" in Mail::Message

$obj->subject

See "The header" in Mail::Message

$obj->timestamp

See "The header" in Mail::Message

$obj->to

See "The header" in Mail::Message

The body

$obj->body([BODY])

See "The body" in Mail::Message

$obj->decoded(OPTIONS)

See "The body" in Mail::Message

$obj->encode(OPTIONS)

See "The body" in Mail::Message

$obj->isMultipart

See "The body" in Mail::Message

$obj->isNested

See "The body" in Mail::Message

$obj->parts(['ALL'|'ACTIVE'|'DELETED'|'RECURSE'|FILTER])

See "The body" in Mail::Message

Flags

$obj->delete

Do not print or send this part of the message anymore. See deleted(). The time stamp of the moment of deletion is stored as value. When the same message is deleted more than once, the first time stamp will stay.

Example:

$message->part(2)->delete;
$part->deleted(1);
delete $part;

$obj->deleted([BOOLEAN])

Set the delete flag for this part of the multipart message body. Without argument, the method returns the same is the isDeleted() method, which is prefered. When a true value is given, delete() is called.

$obj->isDeleted

Returns the moment (as the time function returns) when the message part was flagged for deletion, or undef when the part is not deleted.

Example:

next if $part->isDeleted;

if(my $when = $part->isDeleted) {
   print scalar localtime $when;
}

$obj->isModified

See "Flags" in Mail::Message

$obj->label(LABEL [,VALUE [LABEL, VALUE] ])

See "Flags" in Mail::Message

$obj->labels

See "Flags" in Mail::Message

$obj->modified([BOOLEAN])

See "Flags" in Mail::Message

The whole message as text

$obj->file

See "The whole message as text" in Mail::Message::Construct::Text

$obj->lines

See "The whole message as text" in Mail::Message::Construct::Text

$obj->printStructure([FILEHANDLE][, INDENT])

See "The whole message as text" in Mail::Message::Construct::Text

$obj->string

See "The whole message as text" in Mail::Message::Construct::Text

Internals

$obj->isDelayed

See "Internals" in Mail::Message

$obj->readBody(PARSER, HEAD [, BODYTYPE])

See "Internals" in Mail::Message

$obj->readFromParser(PARSER, [BODYTYPE])

See "Internals" in Mail::Message

$obj->readHead(PARSER [,CLASS])

See "Internals" in Mail::Message

$obj->recursiveRebuildPart(PART, OPTIONS)

See "Internals" in Mail::Message::Construct::Rebuild

$obj->storeBody(BODY)

See "Internals" in Mail::Message

$obj->takeMessageId([STRING])

See "Internals" in Mail::Message

Error handling

$obj->AUTOLOAD

See "METHODS" in Mail::Message::Construct

$obj->defaultTrace([LEVEL, [LEVEL])

Mail::Message::Part->defaultTrace([LEVEL, [LEVEL])

See "Error handling" in Mail::Reporter

$obj->errors

See "Error handling" in Mail::Reporter

$obj->log([LEVEL [,STRINGS]])

Mail::Message::Part->log([LEVEL [,STRINGS]])

See "Error handling" in Mail::Reporter

$obj->logPriority(LEVEL)

Mail::Message::Part->logPriority(LEVEL)

See "Error handling" in Mail::Reporter

$obj->logSettings

See "Error handling" in Mail::Reporter

$obj->notImplemented

See "Error handling" in Mail::Reporter

$obj->report([LEVEL])

See "Error handling" in Mail::Reporter

$obj->reportAll([LEVEL])

See "Error handling" in Mail::Reporter

$obj->shortSize([VALUE])

Mail::Message::Part->shortSize([VALUE])

See "Error handling" in Mail::Message

$obj->shortString

See "Error handling" in Mail::Message

$obj->trace([LEVEL])

See "Error handling" in Mail::Reporter

$obj->warnings

See "Error handling" in Mail::Reporter

Cleanup

$obj->DESTROY

See "Cleanup" in Mail::Message

$obj->destruct

Message parts can not be destructed per part: only whole messages can be forcefully freed from memory. Of course, you can delete() separate parts, which only sets a flag not to write a part again. Furthermore, you may cosider rebuild() to get rit of deleted parts.

$obj->inGlobalDestruction

See "Cleanup" in Mail::Reporter

DIAGNOSTICS

Error: Cannot include forward source as $include.

Unknown alternative for the forward(include). Valid choices are NO, INLINE, and ATTACH.

Error: Cannot include reply source as $include.

Unknown alternative for the include option of reply(). Valid choices are NO, INLINE, and ATTACH.

Error: No address to create forwarded to.

If a forward message is created, a destination address must be specified.

Error: No default mailer found to send message.

The message send() mechanism had not enough information to automatically find a mail transfer agent to sent this message. Specify a mailer explicitly using the via options.

Error: Package $package does not implement $method.

Fatal error: the specific package (or one of its superclasses) does not implement this method where it should. This message means that some other related classes do implement this method however the class at hand does not. Probably you should investigate this and probably inform the author of the package.

Error: You cannot destruct message parts, only whole messages

Message parts can not be destructed per part: only whole messages can be forcefully freed from memory. Consider delete() or rebuild().

Error: no rebuild rule $name defined.

DETAILS

REFERENCES

See the MailBox website at http://perl.overmeer.net/mailbox/ for more details.

COPYRIGHTS

Distribution version 2.044. Written by Mark Overmeer (mark@overmeer.net). See the ChangeLog for other contributors.

Copyright (c) 2001-2003 by the author(s). All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.